<?php
require_once(dirname(__FILE__).DIRECTORY_SEPARATOR.'SprypayCurlException.php');
/**
 * SprypayCurl является небольшой ООП-оберткой над расширением CURL.
 * 
 * @package Sprypaylib
 * @version $id$
 * @copyright 2012 by Sprypay {@link http://sprypay.ru}
 * @license BSD
 */
class SprypayCurl
{
    /**
     * Дескриптор CURL. 
     * 
     * @var resource
     * @access private
     */
    private $curl;

    /**
     * Конструктор класса. 
     * 
     * @param array $options массив с настройками 
     * @access public
     * @return void
     * @throws SprypayCurlException в случае ошибки при создании дексриптора CURL,
     * SprypayCurlException в случае если не обнаружено расширение curl
     */
    public function __construct(array $options = array())
    {
        if (!extension_loaded('curl'))
            throw new SprypayCurlException('Curl extension not found');
        if (!$this->curl = @curl_init())
            throw new SprypayCurlException('Cant create CURL resource');
        if (!empty($options))
            $this->setOptions($options);
    }

    /**
     * Деструктор класса.
     * 
     * @access public
     * @return void
     */
    public function __destruct()
    {
        curl_close($this->curl);
    }

    /**
     * Устанавливает опцию CURL.
     * 
     * @param string $optionName имя опции
     * @param mixed $value значение опции
     * @access public
     * @return bool
     */
    public function setOption($optionName, $value)
    {
        return curl_setopt($this->curl, $optionName, $value);
    }

    /**
     * Устанавливает несколько опций CURL.
     * 
     * @param array $options массив с опциями
     * @access public
     * @return bool
     */
    public function setOptions(array $options)
    {
        return curl_setopt_array($this->curl, $options);
    }

    /**
     * Выполняет запрос.
     * 
     * @access public
     * @return mixed
     * @throws SprypayCurlException в случае ошибок при запросе
     */
    public function execute()
    {
        $result = curl_exec($this->curl);
        if ($result === false) {
            $errorMessage = $this->getLastErrorMessage();
            $errorNumber  = $this->getLastErrorNumber();
            throw new SprypayCurlException($errorMessage, $errorNumber);
        }
        return $result;
    }

    /**
     * Возвращает последнее сообщение об ошибке.
     * 
     * @access private
     * @return string
     */
    private function getLastErrorMessage()
    {
        return curl_error($this->curl);
    }

    /**
     * Возвращает номер последней ошибки. 
     * 
     * @access private
     * @return int
     */
    private function getLastErrorNumber()
    {
        return curl_errno($this->curl);
    }
}
?>
